#!/bin/bash
#
# Transpose a book for alto recorder with C fingering.

if [ $# != 1 ]; then
    echo "Usage: makeAltoRecorderCFingering.sh <book dir name>"
    exit 1
fi

# Transpose up (return 0) if bottom note was < F (< C for recorder).
transposeup()
{
    (($3 < 103))
}

dir=`pwd`

booke=$dir/$1
outdir=$dir/$1-AltoRecorderCFingering

mkdir -p $outdir/Compact

# Copy book component items.
cp $booke/*.txt $booke/*.md $booke/image.jpg $outdir

echo "Alto Recorder (C Fingering)" > $outdir/instrument.txt

find $booke -name "*.abc" |
    while read filename
    do
        name=`basename $filename .abc`

        dir=`dirname $filename`
        basedir=`basename $dir`
        compact=""
        if [ "$basedir" = "Compact" ]; then
            compact="Compact/"
        fi

        range=`./abcrange.py $filename`

        # Transpose concert pitch down a fifth.
        # If there are any notes below 'F' (recorder 'C'), transpose
        # up a seventh instead.
        transpose=-5
        if transposeup $range; then
            transpose=7
        fi

        # There's no point in having transposed chords. Remove from the
        # abc before transposing. Some badly formed chord items can give
        # erroneous output from abc2abc (like, strings of binary gibberish).
        sed -e "s/\"[^\"]*\"//g" $filename > $outdir/$name.abc.tmp

        # Transpose. By default abc2abc will report errors in the output,
        # but this messes up output formatting so stop it.
        abc2abc $outdir/$name.abc.tmp -e -t $transpose > $outdir/$compact$name.abc
        rm $outdir/$name.abc.tmp
    done
