#!/bin/bash
#
# Transpose a book for alto saxophone

if [ $# != 1 ]; then
    echo "Usage: makeAltoSax.sh <book dir name>"
    exit 1
fi

dir=`pwd`

booke=$dir/$1
outdir=$dir/$1-AltoSax

mkdir -p $outdir/Compact

# Copy book component items.
cp $booke/*.txt $booke/*.md $booke/image.jpg $outdir

echo "Alto Saxophone" > $outdir/instrument.txt

find $booke -name "*.abc" |
    while read filename
    do
        name=`basename $filename .abc`

        dir=`dirname $filename`
        basedir=`basename $dir`
        compact=""
        if [ "$basedir" = "Compact" ]; then
            compact="Compact/"
        fi

        range=`./abcrange.py $filename`

        # Transpose concert pitch down a minor third.
        transpose=-3

        # There's no point in having transposed chords. Remove from the
        # abc before transposing. Some badly formed chord items can give
        # erroneous output from abc2abc (like, strings of binary gibberish).
        sed -e "s/\"[^\"]*\"//g" $filename > $outdir/$name.abc.tmp

        # Transpose. By default abc2abc will report errors in the output,
        # but this messes up output formatting so stop it.
        abc2abc $outdir/$name.abc.tmp -e -t $transpose > $outdir/$compact$name.abc
        rm $outdir/$name.abc.tmp
    done
