#!/bin/bash
#
# Generate the LaTeX for the Booke tune pages (tunes.tex) and the index
# of first lines (firstlines.tex). These are generated into the build
# directory.
#
# All EPS and PDF tune graphics must be present already. Run
# makeGraphics.sh to make these.
#

usecompact=""

if [ $# -gt 1 -a "$1" = "--use-compact" ]; then
    usecompact="yes"
    shift
fi

if [ $# != 1 ]; then
    echo "Usage: makeBookeTunePages.sh [--use-compact] <book dir name>"
    exit 1
fi

dir=`pwd`

booke=$dir/$1
builddir=$dir/build
graphicsdir=$dir/graphics/$1
tunesoutput=$builddir/$1-tunes.tex
indexoutput=$builddir/$1-firstlines.tex

mkdir -p $builddir

rm -f $tunesoutput $indexoutput

# Now, for each tune, build the tunes part and the first line sections
# of the document.
find $booke -maxdepth 1 -name "*.abc" | LC_ALL=C sort |
    while read filename
    do
        name=`basename $filename .abc`
        tuneimagefile="${graphicsdir}/${name}"
        compacttuneimagefile="${graphicsdir}/compact-${name}"
        firstlineimagefile="${graphicsdir}/firstline-${name}"

        if [ "$usecompact" -a -f ${compacttuneimagefile}.pdf ]; then
            tuneimagefile=$compacttuneimagefile
        fi

        $dir/abctemplate.py \
            --latex \
            --value "tuneimagefile=${tuneimagefile}" \
            --template $dir/dottes.tex.tune \
            $filename >> $tunesoutput
        $dir/abctemplate.py \
            --latex \
            --value "firstlineimagefile=${firstlineimagefile}" \
            --template $dir/dottes.tex.firstline-tune \
            $filename >> $indexoutput
    done
